@@ -14,23 +14,10 @@ has_element 'items' =>
 	is => "ro",
 	isa => "ArrayRef[XML::EPP::Host::Check::Status]",
 	xml_nodeName => "cd",
-	required => 1,
 	;
 
 1;
 
-=head1 NAME
-
-? - implement ?
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
 =head2 XML Schema Definition
 
  <complexType name="chkDataType">
