@@ -11,7 +11,6 @@ has_element 'name_status' =>
 	isa => "ArrayRef[XML::EPP::Host::Check::Name]",
 	xml_nodeName => "name",
 	handles => [qw(available name)],
-	required => 1,
 	;
 
 has_element "reason" =>
@@ -23,18 +22,6 @@ has_element "reason" =>
 
 1;
 
-=head1 NAME
-
-? - implement ?
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
 =head2 XML Schema Definition
 
  <complexType name="checkType">
