@@ -24,7 +24,6 @@ has_element 'status' =>
 	is => "ro",
 	isa => "ArrayRef[XML::EPP::Host::Status]",
 	xml_max => 7,
-	required => 1,
 	;
 
 use XML::EPP::Host::Address;
@@ -76,18 +75,6 @@ has_element 'transferred' =>
 
 1;
 
-=head1 NAME
-
-? - implement ?
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
 =head2 XML Schema Definition
 
  <!--
