@@ -15,14 +15,12 @@ has_element 'name_result' =>
 	isa => "XML::EPP::Host::Notification::Result",
 	handles => [qw(name approved)],
 	xml_nodeName => "name",
-	required => 1,
 	;
 
 has_element 'tx_id' =>
 	is => "ro",
 	isa => "XML::EPP::TrID",
 	xml_nodeName => "paTRID",
-	required => 1,
 	;
 
 has_element 'tx_when' =>
@@ -33,19 +31,7 @@ has_element 'tx_when' =>
 
 1;
 
-=head1 NAME
-
-XML::EPP::Host::Notification - implement panDataType
-
-=head1 SYNOPSIS
-
-TODO
-
-=head1 DESCRIPTION
-
-...
-
-=head2 XML Schema Definition
+=head2 XMLSchema definition
 
  <!--
  Pending action notification response elements.
