@@ -12,38 +12,30 @@ our $SCHEMA_PKG = "XML::EPP";
 use XML::EPP;
 use XML::EPP::Common;
 
-has_element 'client_id' =>
+has_element 'clID' =>
 	is => "rw",
 	isa => "XML::EPP::Common::clIDType",
-	xml_nodeName => "clID",
-	required => 1,
 	;
 
-has_element 'password' =>
+has_element 'pw' =>
 	is => "rw",
 	isa => "${SCHEMA_PKG}::pwType",
-	xml_nodeName => "pw",
-	required => 1,
 	;
 
-has_element 'new_password' =>
+has_element 'newPW' =>
 	is => "rw",
-	predicate => "has_new_password",
+	predicate => "has_newPW",
 	isa => "${SCHEMA_PKG}::pwType",
-	xml_nodeName => "newPW",
 	;
 
 has_element 'options' =>
 	is => "rw",
 	isa => "${SCHEMA_PKG}::credsOptionsType",
-	required => 1,
 	;
 
-has_element 'services' =>
+has_element 'svcs' =>
 	is => "rw",
 	isa => "${SCHEMA_PKG}::loginSvcType",
-	xml_nodeName => "svcs",
-	required => 1,
 	;
 
 with 'XML::EPP::Node';
