@@ -11,7 +11,6 @@ has_element 'content' =>
 	is => "rw",
 	isa => "PRANG::XMLSchema::normalizedString",
 	xml_nodeName => "",
-	required => 1,
 	;
 
 has_attr 'lang' =>
@@ -25,11 +24,4 @@ with 'XML::EPP::Node';
 subtype "${SCHEMA_PKG}::msgType"
 	=> as __PACKAGE__;
 
-coerce "${SCHEMA_PKG}::msgType"
-	=> from "Str"
-	=> via {
-		m{\A\s*(\S.*\S)\s*\Z};
-		__PACKAGE__->new(content => $1||"(none)");
-	};
-
 1;
