@@ -2,7 +2,6 @@
 package XML::EPP::Response;
 
 use Moose;
-use MooseX::StrictConstructor;
 use MooseX::Method::Signatures;
 use Moose::Util::TypeConstraints;
 use PRANG::Graph;
@@ -14,7 +13,6 @@ use XML::EPP::Result;
 has_element 'result' =>
 	is => "rw",
 	isa => "ArrayRef[${SCHEMA_PKG}::resultType]",
-	required => 1,
 	;
 
 use XML::EPP::MsgQ;
@@ -26,11 +24,10 @@ has_element 'msgQ' =>
 
 use XML::EPP::SubResponse;
 
-has_element 'response' =>
+has_element 'resData' =>
 	is => "rw",
 	isa => "${SCHEMA_PKG}::SubResponse",
-	predicate => "has_response",
-	xml_nodeName => "resData",
+	predicate => "has_resData",
 	;
 
 has_element 'extension' =>
@@ -39,11 +36,9 @@ has_element 'extension' =>
 	predicate => "has_extension",
 	;
 
-has_element 'tx_id' =>
+has_element 'trID' =>
 	is => "rw",
 	isa => "${SCHEMA_PKG}::trIDType",
-	xml_nodeName => "trID",
-	required => 1,
 	;
 
 with 'XML::EPP::Node';
